Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/FCKeditor.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/FCKeditor.java	(revision 1681)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/FCKeditor.java	(revision 1682)
@@ -31,6 +31,11 @@
 /**
  * FCKeditor control class.<br>
- * It's the container for all properties and the class that generate the output based on browser
- * capabilities and configurations passed by the developer.
+ * 
+ * It creates the html code for the FCKeditor based on the following things:
+ * <ul>
+ * <li>browser's capabilities</li>
+ * <li>different properties settings managed by the {@link PropertiesLoader}</li>
+ * <li>settings from the 'caller', eg. jsp-pages</li>
+ * </ul>
  * 
  * @version $Id$
@@ -43,6 +48,6 @@
 	private String basePath;
 	private HttpServletRequest request;
-	
-	//defaults
+
+	// defaults
 	private String toolbarSet = PropertiesLoader.getProperty("fckeditor.toolbarSet");
 	private String width = PropertiesLoader.getProperty("fckeditor.width");
@@ -51,7 +56,7 @@
 
 	/**
-	 * Initialize the object setting all basic configurations.<br>
-	 * 
-	 * The basePath is context root + {@link ConnectorHandler#getFckEditorBasePath()}.
+	 * Main constructor.<br>
+	 * All important settings are done here and will be preset by there defaults taken from
+	 * {@link PropertiesLoader}.
 	 * 
 	 * @param request
@@ -66,7 +71,7 @@
 	 *            toolbarSet name
 	 */
-	public FCKeditor(final HttpServletRequest request,
-			final String instanceName, final String width, final String height,
-			final String toolbarSet, final String value, final String basePath) {
+	public FCKeditor(final HttpServletRequest request, final String instanceName,
+	        final String width, final String height, final String toolbarSet, final String value,
+	        final String basePath) {
 		this.request = request;
 		this.instanceName = instanceName;
@@ -86,5 +91,5 @@
 		config = new FCKeditorConfig();
 	}
-	
+
 	/**
 	 * Just a wrapper to {@link FCKeditor}.
@@ -186,5 +191,5 @@
 
 	private String escapeXml(String txt) {
-		if(Utils.isEmpty(txt))
+		if (Utils.isEmpty(txt))
 			return txt;
 		txt = txt.replaceAll("&", "&#38;");
@@ -202,5 +207,5 @@
 		return createHtml();
 	}
-	
+
 	@Override
 	public String toString() {
@@ -232,5 +237,6 @@
 
 			// create IFrame
-			String sLink = basePath.concat("/editor/fckeditor.html?InstanceName=").concat(instanceName);
+			String sLink = basePath.concat("/editor/fckeditor.html?InstanceName=").concat(
+			        instanceName);
 			if (Utils.isNotEmpty(toolbarSet))
 				sLink += "&Toolbar=".concat(toolbarSet);
Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/ConnectorHandler.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/ConnectorHandler.java	(revision 1681)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/ConnectorHandler.java	(revision 1682)
@@ -22,4 +22,6 @@
 
 import javax.servlet.http.HttpServletRequest;
+
+import net.fckeditor.SessionData;
 
 /**
@@ -54,5 +56,5 @@
 	 * XML response rather than the absolute URL.
 	 * 
-	 * @return
+	 * @return Boolean value of the property 'connector.fullUrl'.
 	 */
 	public static boolean isFullUrl() {
@@ -72,5 +74,5 @@
 	 * Getter for the value to instruct the Connector to check, if the uploaded image is really one.
 	 * 
-	 * @return
+	 * @return Boolean value of the property 'connector.secureImageUploads'.
 	 */
 	public static boolean isSecureImageUploads() {
Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/SessionDataHandler.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/SessionDataHandler.java	(revision 1681)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/handlers/SessionDataHandler.java	(revision 1682)
@@ -82,5 +82,5 @@
 	 * 
 	 * @param request
-	 * @return {@link SessionData#getUserFilesPath(HttpServletRequest} or null, if sessionData is
+	 * @return {@link SessionData#getUserFilesPath(HttpServletRequest)} or null, if sessionData is
 	 *         null.
 	 */

Index: /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/SessionData.java
===================================================================
--- /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/SessionData.java	(revision 1681)
+++ /FCKeditor.Java/branches/2.4/src/main/java/net/fckeditor/SessionData.java	(revision 1682)
@@ -23,25 +23,23 @@
 import javax.servlet.http.HttpServletRequest;
 
+import net.fckeditor.handlers.ConnectorHandler;
+
 /**
- * Interface to provide session or request based functionality to
- * FCKeditor.Java. Currently, the implemeted class has to implement the
- * following:
+ * Interface to provide session or request based functionality to FCKeditor.Java. Currently, the
+ * implemeted class has to implement the following:
  * <ul>
  * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user
  * to browse/select file.</li>
  * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user
  * to upload files.</li>
  * <li>{@link #getUserFilesPath(HttpServletRequest)}: Constructs an user based
  * 'BaseDir'.</li>
  * </ul>
  * {@link #isEnabledForFileBrowsing(HttpServletRequest)} and
- * {@link #isEnabledForFileUpload(HttpServletRequest)} are authentification
- * methodes for different kinds of user actions.<br />
+ * {@link #isEnabledForFileUpload(HttpServletRequest)} are authentification methods for different
+ * kinds of user actions.<br />
  * <br />
- * This class is managed by {@link ConfigurationHandler}.<br />
- * <br />
- * <b>Warning for commiters: </b>You have to awake that every change of this
- * interface could break all classes which implemented this interface. Therefore
- * you should change this interface for milestone releases only!
+ * <b>Warning for commiters: </b>You have to awake that every change of this interface could break
+ * all classes which implemented this interface. Therefore you should change this interface for
+ * milestone releases only!
  * 
  * @version $Id$
@@ -55,6 +53,5 @@
 	 * @param request
 	 *            Servlet request from user
-	 * @return <code>true</code> if user can upload to the server else
-	 *         <code>false</code>
+	 * @return <code>true</code> if user can upload to the server else <code>false</code>
 	 */
 	public boolean isEnabledForFileUpload(final HttpServletRequest request);
@@ -66,6 +63,5 @@
 	 * @param request
 	 *            Servlet request from user
-	 * @return <code>true</code> if use can browse the server else
-	 *         <code>false</code>
+	 * @return <code>true</code> if use can browse the server else <code>false</code>
 	 */
 	public boolean isEnabledForFileBrowsing(final HttpServletRequest request);
@@ -75,9 +71,7 @@
 	 * <b>Important:</b>
 	 * <ul>
 	 * <li> If the implementation returns <code>null</code>,
 	 * {@link ConfigurationHandler} will used the default one! That's useful, if
 	 * the implementation doesn't bother you.</li>
 	 * <li>The returned directory string has to start with '/', but has to end
 	 * without '/'.</li>
 	 * <li>The dir has to be within the context</li>
 	 * </ul>
@@ -23,25 +23,23 @@
  * <ul>
- * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user
- * to browse/select file.</li>
- * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user
- * to upload files.</li>
- * <li>{@link #getUserFilesPath(HttpServletRequest)}: Constructs an user based
- * 'BaseDir'.</li>
+ * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user to browse/select
+ * file.</li>
+ * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user to upload files.</li>
+ * <li>{@link #getUserFilesPath(HttpServletRequest)}: It is used by
+ * {@link ConnectorHandler#getUserFilesPath(HttpServletRequest)} to build an user based 'BaseDir'.</li>
  * </ul>
  * {@link #isEnabledForFileBrowsing(HttpServletRequest)} and
@@ -75,9 +71,7 @@
 	 * <b>Important:</b>
 	 * <ul>
-	 * <li> If the implementation returns <code>null</code>,
-	 * {@link ConfigurationHandler} will used the default one! That's useful, if
-	 * the implementation doesn't bother you.</li>
-	 * <li>The returned directory string has to start with '/', but has to end
-	 * without '/'.</li>
+	 * <li> If the implementation returns <code>null</code>, {@link ConnectorHandler} will used
+	 * the default one! That's useful, if the implementation doesn't bother you.</li>
+	 * <li>The returned directory string has to start with '/', but has to end without '/'.</li>
 	 * <li>The dir has to be within the context</li>
 	 * </ul>